import * as config from './linkedin/lisn.config';
/**
 * @用途 通讯类，linkedin、facebook等通讯
 * @author 黄敏
 * @创建时间 2022-08-11 10:26
 **/
interface CancelCb {
    (cancel: Axios.Canceler): void;
}
export declare enum LinkedinAccount {
    nologin = 1,
    default = 2,
    sales = 3
}
interface liErr {
    code: number;
    msg: string;
    time: number;
    type: string;
    conn_m: number;
}
interface LinkedinContactInfo {
    birthDateOn?: {
        month: number;
        day: number;
    };
    connectedAt?: number;
    emailAddress?: string;
    entityUrn: string;
    twitterHandles: [];
}
declare class Linkedin {
    readonly config: Readonly<typeof config>;
    readonly nologin = 1;
    readonly default = 2;
    readonly sales = 3;
    login_status: number;
    login_number_id: number;
    current_user: Crawler.ContactAnchorFriends | null;
    getCompanyId(url: string): string | undefined;
    getContactId(url: string): string | undefined;
    getDBContact(UID: string): Promise<Crawler.Contact | null>;
    /**
     * 获取linkedin的好友申请数量
     * */
    getInvitationCount(): Promise<any>;
    /**
     * 获取linkedin的好友申请列表
     * */
    getInvitationList(page?: number, size?: number): Promise<any>;
    getCurrentUser(): Promise<Crawler.ContactAnchorFriends>;
    /**
     * 获取联系人基本信息
     * @param {String} linkedin ID
     * @param {noFriend} 不需要获取好友关系（好友关系需要请求多个接口）
     * @returns {Object} Crawler.Contact
     * */
    getContactBase(UID: string, noFriend?: boolean): Promise<Crawler.Contact | null>;
    get liErr(): {
        get(): any;
        set(liErr: liErr): void;
        remove(): void;
    };
    /**
     * 'https://www.linkedin.com/pub/vlad-cealicu/2/807/29a'
     * linkedin 老格式转换，/pub/vlad-cealicu/2/807/29a
     * */
    pubToIn(url: string): Promise<string>;
    /**
     * 提取图片信息
     * @param {{artifacts: any[]; rootUrl: string}} picture linkedin通用格式
     * */
    extractImageUrl(picture: {
        artifacts: any[];
        rootUrl: string;
    }): string;
    getToken(): Promise<string>;
    /**
     * 获取当前登录者 数字ID
     * https://www.linkedin.com/psettings/policy/notices?types=COMMENTS_VISIBILITY
     * */
    getNumberId(): Promise<number>;
    /**
     * 获取linkedin的密文id
     * @param {string} uid uid是连接中 https://www.linkedin.com/in/yourk-soboros-181b0a63 中的 yourk-soboros-181b0a63
     * */
    getUrnId(uid: string): Promise<string>;
    ajaxErrorHandle(e: any): void;
    ajax(url: string, data?: {
        [key: string]: any;
    }, type?: 'get' | 'post', cancelCb?: CancelCb, headers?: {
        [key: string]: string | number;
    }): Promise<any>;
    getEndId(urn: string | undefined): string;
    getLinkedinInfo(uid: string): Promise<LinkedinContactInfo>;
    getFriendInfo(uid: string, noCache?: boolean): Promise<Crawler.FriendInfo>;
    getConnections(url?: string): Promise<Crawler.Result>;
}
export default Linkedin;
